@@ -284,16 +284,45 @@ class DB:
         :return: False - DB Error | True - insert successfully
         """
 
-        if isinstance(data, dict):
-            names = list(data)
-            cols = ', '.join(map(escape_name, names))
-            placeholders = ', '.join([f'%({name})s' for name in names])
-            query = f'INSERT INTO `{tbl}` ({cols}) VALUES ({placeholders})'
-        else:
+        if not isinstance(data, dict):
             return False
 
+        names = list(data)
+        cols = ', '.join(map(escape_name, names))
+        placeholders = ', '.join([f'%({name})s' for name in names])
+        query = f'INSERT INTO `{tbl}` ({cols}) VALUES ({placeholders})'
+
         conn = kwargs['conn']
         with conn.cursor() as cur:
             cur.execute(query, data)
         conn.commit()
         return True
+
+    @query
+    def insertmany(self, tbl, data, **kwargs):
+        """
+        Insert one row into table
+        :param tbl:
+        :param data:
+        :return: False - DB Error | True - insert successfully
+        """
+
+        if not isinstance(data, (list, tuple)):
+            return False
+
+        if len(data) == 0:
+            return False
+
+        names = list(data[0])
+        cols = ', '.join(map(escape_name, names))
+        placeholders = ', '.join([f'%({name})s' for name in names])
+        query = f'INSERT INTO `{tbl}` ({cols}) VALUES ({placeholders})'
+
+        if kwargs.get('foreign_key_checks') == 0:
+            query = f'SET FOREIGN_KEY_CHECKS=0; {query}'
+
+        conn = kwargs['conn']
+        with conn.cursor() as cur:
+            cur.executemany(query, data)
+        conn.commit()
+        return True
